==> matrix-synapse_0.24.0+dfsg.orig.tar.gz: synapse-0.24.0/.github/ISSUE_TEMPLATE.md <==
<!-- 

**IF YOU HAVE SUPPORT QUESTIONS ABOUT RUNNING OR CONFIGURING YOUR OWN HOME SERVER**: 
You will likely get better support more quickly if you ask in ** #matrix:matrix.org ** ;)


This is a bug report template. By following the instructions below and
filling out the sections with your information, you will help the us to get all
the necessary data to fix your issue.

You can also preview your report before submitting it. You may remove sections
that aren't relevant to your particular case.

Text between <!-- and --​> marks will be invisible in the report.

-->

### Description

Describe here the problem that you are experiencing, or the feature you are requesting.

### Steps to reproduce

- For bugs, list the steps
- that reproduce the bug
- using hyphens as bullet points

Describe how what happens differs from what you expected.

If you can identify any relevant log snippets from _homeserver.log_, please include
those here (please be careful to remove any personal or private data):

### Version information

<!-- IMPORTANT: please answer the following questions, to help us narrow down the problem -->

- **Homeserver**: Was this issue identified on matrix.org or another homeserver?

If not matrix.org:
- **Version**:        What version of Synapse is running? <!-- 
You can find the Synapse version by inspecting the server headers (replace matrix.org with
your own homeserver domain):
$ curl -v https://matrix.org/_matrix/client/versions 2>&1 | grep "Server:"
-->
- **Install method**: package manager/git clone/pip      
- **Platform**:       Tell us about the environment in which your homeserver is operating
                      - distro, hardware, if it's running in a vm/container, etc.

==> matrix-synapse_0.33.8.orig.tar.gz: synapse-0.33.8/.github/ISSUE_TEMPLATE.md <==
<!-- 

**IF YOU HAVE SUPPORT QUESTIONS ABOUT RUNNING OR CONFIGURING YOUR OWN HOME SERVER**: 
You will likely get better support more quickly if you ask in ** #matrix:matrix.org ** ;)


This is a bug report template. By following the instructions below and
filling out the sections with your information, you will help the us to get all
the necessary data to fix your issue.

You can also preview your report before submitting it. You may remove sections
that aren't relevant to your particular case.

Text between <!-- and --​> marks will be invisible in the report.

-->

### Description

Describe here the problem that you are experiencing, or the feature you are requesting.

### Steps to reproduce

- For bugs, list the steps
- that reproduce the bug
- using hyphens as bullet points

Describe how what happens differs from what you expected.

<!-- If you can identify any relevant log snippets from _homeserver.log_, please include
those (please be careful to remove any personal or private data). Please surround them with
``` (three backticks, on a line on their own), so that they are formatted legibly. -->

### Version information

<!-- IMPORTANT: please answer the following questions, to help us narrow down the problem -->

- **Homeserver**: Was this issue identified on matrix.org or another homeserver?

If not matrix.org:
- **Version**:        What version of Synapse is running? <!-- 
You can find the Synapse version by inspecting the server headers (replace matrix.org with
your own homeserver domain):
$ curl -v https://matrix.org/_matrix/client/versions 2>&1 | grep "Server:"
-->
- **Install method**: package manager/git clone/pip      
- **Platform**:       Tell us about the environment in which your homeserver is operating
                      - distro, hardware, if it's running in a vm/container, etc.
